@@ -1,15 +1,5 @@
-import sys
-
-from ._version import __version__
-from .widget import AnyWidget
-
-try:
-    if "google.colab" in sys.modules:
-        from google.colab import output  # type: ignore
-
-        output.enable_custom_widget_manager()
-except ImportError:
-    pass
+from ._version import __version__  # noqa
+from .widget import AnyWidget  # noqa
 
 
 def _jupyter_labextension_paths():
